# WIP

# ReunionLog

## About repository

### Purpose

The main purpose of this small code sample is to access the data of **warcraftlogs** by their own API.

Then by gaining access we would then download the date to output specific values in a .csv file extension.

> What data we want to be in our .csv file will be in the main.py file. The functionality will be in the /src directory.

### About me

This is a repository maintained by me *Nickgismokato* on the request of the guild who want to use this data gained from warcraftlogs.

### The guild

The guild in world of warcraft is the guild **Reunion**. This guild is not unaware of the code i create and maintain. Though most of the members is unaware, the officers of the guild know of this.

## About WarcraftLogs and  OAuth 2

### WarcraftLogs

[WarcraftLogs](https://www.warcraftlogs.com) is a website where guilds and indiviuels can put up there logs from raids, dungeons, etc. from the popular game [World Of Warcraft](https://worldofwarcraft.com).

> This repository will not contain the function to upload logs. How to to it can be found [here](https://www.warcraftlogs.com/help/start).

### OAuth

**WarcraftLogs** uses **OAuth 2.0** for API authentication. 

More can be read at [WarcraftLogs APIv2](https://www.warcraftlogs.com/api/docs).

